#
# spec file for package mined
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mined
Version:        2014.24.2
Release:        133.2
Summary:        Powerful Text Editor with Extensive Unicode and CJK Support
License:        GPL-3.0+
Group:          Productivity/Editors/Other
Url:            http://towo.net/mined/
Source:         http://towo.net/mined/download/mined-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  update-desktop-files
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Mined is a powerful text editor with a comprehensive yet concise and
easy-to-use user interface supporting modern interaction paradigms,
and fast, small-footprint behaviour.

Mined provides both extensive Unicode and CJK support offering many
specific features and covering special cases that other editors
are not aware of (like auto-detection features and automatic handling
of terminal variations, or Han character information).
It was the first editor that supported Unicode in a plain-text terminal
(like xterm or rxvt).

%package -n xmined
Summary:        Graphical interface using Xterm of Mined text editor
Group:          Productivity/Editors/Other
Requires:       mined = %{version}
%if 0%{?suse_version} > 1320
Requires:       xterm-bin
%else
Requires:       xterm
%endif

%description -n xmined
Mined is a powerful text editor with a comprehensive yet concise and
easy-to-use user interface supporting modern interaction paradigms,
and fast, small-footprint behaviour.

Mined provides both extensive Unicode and CJK support offering many
specific features and covering special cases that other editors
are not aware of (like auto-detection features and automatic handling
of terminal variations, or Han character information).
It was the first editor that supported Unicode in a plain-text terminal
(like xterm or rxvt).

%prep
%setup -q
# desktop file fix
sed -i "s/mined.xpm/mined/" ./usrshare/setup_install/mined.desktop
sed -i s/Utility/Utility\;/ ./usrshare/setup_install/mined.desktop

%build
%configure
make OPT="%{optflags}" USRLIBDIR=%{_libdir} ROOTLIBDIR=/%{_lib} %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

# fix links
rm -rf %{buildroot}%{_bindir}/{minmacs,mpico,mstar}
for i in minmacs mpico mstar ; do
	ln -sf %{_bindir}/mined %{buildroot}%{_bindir}/${i}
done

# Documentation
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/%{name}/doc_user/* %{buildroot}%{_docdir}/%{name}/
mv %{buildroot}%{_datadir}/%{name}/package_doc/* %{buildroot}%{_docdir}/%{name}/
# CHANGES -> doc_user/changes.html
rm -rf %{buildroot}%{_docdir}/%{name}/CHANGES

# Remove files for Windows but needed for build
# and useless directories (package_doc, doc_user)
rm -rf %{buildroot}%{_datadir}/%{name}/bin/
mv %{buildroot}%{_datadir}/%{name}/setup_install/bin %{buildroot}%{_datadir}/%{name}/
rm -rf %{buildroot}%{_datadir}/%{name}/{setup_install,doc_user,package_doc}

%suse_update_desktop_file %{name} TextEditor Utility

%fdupes %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/mined
%{_bindir}/minmacs
%{_bindir}/mpico
%{_bindir}/mstar
%{_mandir}/man1/mined.1.gz
%{_mandir}/man1/minmacs.1.gz
%{_mandir}/man1/mpico.1.gz
%{_mandir}/man1/mstar.1.gz
%{_datadir}/%{name}
%doc %{_docdir}/%{name}

%files -n xmined
%defattr(-,root,root)
%{_bindir}/umined
%{_bindir}/uterm
%{_bindir}/xmined
%{_mandir}/man1/umined.1.gz
%{_mandir}/man1/uterm.1.gz
%{_mandir}/man1/xmined.1.gz
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.xpm

%changelog
* Wed Dec 17 2014 dimstar@opensuse.org
- On openSUSE > 13.2, xterm has been split into xterm-bin for the
  program and xterm for the app launcher. We only need the program,
  so conditionall Require xterm-bin.
* Wed Jul 16 2014 i@marguerite.su
- remake specfile. I can't understand why use makefile.linux
  when you have a configure file
- split xmined like Fedora did.
- redownload tarball 'coz previous one has different contents
  thus can't pass Factory check
- delete mined.dsc, which is used for deb
* Wed Jul 16 2014 coolo@suse.com
- fix spec file and changes
* Mon Jul  7 2014 towo@towo.net
  Update to mined 2014.24.2 - highlights:
  New upstream releases.
    • 2014.24 is a major update with a list of new features and enhancements.
  Internationalization and Character information:
    • Updated to Unicode 7.0.
    • Revamped smart quotes feature.
    – Revised Quotes menu according to investigations of international styles.
    – Supporting opening quotation mark repetition for new paragraphs.
    – Automatic French quotation marks spacing.
    – Primary/alternate styles controlled by locale environment or option.
  Editing:
    • File tabs and file name tab titles for quick file selection and browsing.
    • Tuned special title casing (Shift-F3) e.g. for Dutch "IJsselmeer".
    • Improved and line end handling in search/replace.
    • Revamped rectangular text selection.
    – Toggle with Alt-mouse-move during click-and-drag.
    – Consistent selection to mouse position (even on shorter lines) including shifted lines.
    • Revamped and enhanced HTML and scripting highlighting.
    – Distinct highlighting for HTML/XML/JSP attributes and values.
    • TAB width 2 enabled in addition to 4 or 8.
    • Smarter clipboard pasting (cygwin/Windows).
  User configuration:
    • Enhanced user configuration features.
    – Preferences specific for file name pattern or terminal type.
    – Consistent handling of preferences when editing multiple files.
    – Added cursor style setting preference.
  File handling improvements
  Terminal interworking improvements
    • (mlterm, tmux, older xterm, missing terminfo, CJK in 'screen')
    • Interworking with Windows PowerShell and xterm 306 dim mode.
  Bug fixes:
    • File handling: Various pipe handling fixes.
    • File handling: Detecting "quota exceeded" write error.
    • Case conversion function fixes.
    • Handling search expressions with ^M or \r.
    • Keyboard: Ctrl-Backarrow again deleting only one character.
    • Fixed some menu handling cases.
    • Fixed input of typographic apostrophe in some cases.
    • Made file basename visible in long prompt lines.
    • HTML highlighting cases, especially after insert.
* Sun Aug 18 2013 towo@towo.net
  Update to mined 2013.23 - highlights:
  Editing:
  • New double-click feature for word selection.
  • Tweaks on smart editing features (undent, wrap, identifier search etc).
  Filename handling:
  • Suppressing backup file names as generated by command line
  auto-completion if they appear after their base version name
  (x~, x;N, x.~N~), so that, e.g., mined x* edits x and x1 but not x~.
  Character information:
  • Updated to Unicode 6.2.
  Interworking:
  • Speed-up of directory browsing, especially on slow network drives.
  • Ported stand-alone Windows installer to Windows 7.
  • Ported to MSYS, Raspberry Pi, Irix.
  • Revamped file information statistics to accomodate slow systems.
  • Enhancements for newer mlterm.
  Bug fixes:
  • Explicit tab width option (-4/-8) takes precedence over file info memory.
  • Fix 'screen' Unicode display by limiting previous workaround to older version.
  • Fixed Alt-digit accent prefix functions for mintty and rxvt (since 2012.20).
  • Fixes related to NUL or NONE pseudo lineends.
  Thu, 10 May 2012 00:00:00 CEST - towo@towo.net
  Update to mined 2012.22 - highlights of last 3 releases:
  User configuration:
  • New user preferences configuration file $HOME/.minedrc.
  Interactive:
  • New File switcher: menu listing of opened files (tab-like).
  • New Shift selection mode: visual selection with Shift-keys (Windows-like).
  • Backarrow now also performs dual-mode function like Del.
  • Revamped keypad function modes and their setup, including
  more interoperable handling of Home/End keys.
  • Enabled opening flag menu on terminals missing mouse
  right-click support (e.g. gnome-terminal).
  Character information:
  • Updated to Unicode 6.1.
  Interworking:
  • Mouse moving interaction works in rxvt-unicode / urxvt as well.
  • Fixed terminal detection and attribute handling for 'screen'.
  • Workarounds for configuration problems with various terminals.
  • Optimized escape sequence detection for slow terminal connections.
* Thu Mar  8 2012 cfarrell@suse.com
- license update: GPL-3.0+
  No indication of GPL-3.0 (only) license
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Sat Nov 12 2011 towo@towo.net
  Update to mined 2011.19
  This release features major enhancements in file management:
  • Interactive file chooser to navigate file system.
  • Backup files, interoperable with other editors; optional numbered backups.
  • File locking, using interoperable lock files.
  • Recovery files (if mined quits), interoperable with other editors.
  • Checking/warning whether disk file was changed while being edited (2011.18).
  • Enhancement and migration of file info storage (2011.18).
  Other major enhancements in this release:
  Interactive:
  • Mouse movement navigation between menus, especially to open submenus.
  Interworking and Deployment:
  • Using glyph detection feature of mintty for optimal marker selection.
  • Assigned HOP function to Shift-TAB and to keypad "*", to support
  laptop keyboards and some dumb terminals (KDE konsole, BSD console).
  • Windows stand-alone package: Installing into Start Menu and Desktop.
  • Enhanced Linux desktop integration (2011.18).
  • Other interoperability and portability enhancements,
  including port to Haiku (2011.18).
* Wed Jun  8 2011 towo@towo.net
- update to mined 2011.17
  Major enhancements in this release:
  Character encoding support enhancements:
  • Updated to Unicode 5.2 and Unicode 6.0:
  • Supporting Arabic ligature joining in all terminals.
  Interactive:
  • Sub-menu (in Options menu) to change keyboard emulation interactively.
  • Improved display of status line information.
  • Automatically adjusting HTML syntax highlighting colour to dark background.
  • Improved file info handling, includes selected input method.
  • Interactive help viewing uses mined rather than less.
  Interworking:
  • Supporting extended mouse-coordinates mode (xterm 262 and 268,
    mintty 0.9), for up to 2015 lines/columns screen width.
  • Improved handling of function keys on badly-configured terminals.
  Bug fixes:
  • Fixed keyboard mapping in xterm to accept sequences with
    subsequent capital letters (like hE, HE).
  • Fixed printing under Windows and Interix.
  • Fixed UTF-16 handling.
  • Fixed stalled mined with modified text after terminal is killed on Linux.
* Thu Jun 10 2010 llunak@novell.com
- update to mined 2000.16.
  Major enhancements in this release:
  Text editing features:
  • New rectangular copy/paste area mode.
  • Enhanced smart quotes algorithm and input support for apostrophe.
  • Support fow Hawai'ian input.
  Interactive:
  • Self-made visual selection highlighting, supporting all terminals.
  • Changed Del keypad key to more common behaviour.
  • Calculated dim attribute for line markers in xterm and mintty.
  • Enabled keyboard mapping (input method handling) for DOS/djgpp version.
  • Menu navigation: On a submenu entry, cursor-right enters the submenu too.
  File handling:
  • The text position is now more easily remembered.
* Sun May  9 2010 meissner@suse.de
- patch makefile.gcc, not makefile.linux (latter is a symlink to first)
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Sep 18 2007 ro@suse.de
- fix build on lib64 platforms
* Thu Jul 19 2007 mfabian@suse.de
- update to mined 2000.14.
  Major enhancements in this release:
  Text editing features:
  • Case-insensitive search (except when searching for an
  identifier).
  • New command Alt-x toggles preceding character and its
  hexadecimal code.
  Character encoding support enhancements:
  • Additional option -E? just determines and displays text file
  encoding(s).
  • Additional option +E? just determines and displays terminal
  encoding.
  • Separated display of "isolated" combining characters
  (e.g. after TAB).
  • Improved text encoding auto-detection:
    • Improved detection of CJK encodings vs. 8-bit encodings.
    • Added auto-detection of Windows-"ANSI" (CP1252),
    PC-Latin (CP850), MacRoman.
    • Improved configuration of auto-detection.
  Character input enhancements:
  • New shortcuts for input of plain quote marks (in smart
  quotes mode).
  Interworking enhancements:
  • Terminal encoding handling:
    • Added options -f / -F to indicate limited font coverage of
    special characters.
    • Detecting and handling non-Unicode terminal with Arabic
    ligature joining.
    • Detecting and handling special width behaviour of rxvt,
    mlterm, konsole concerning unassigned characters, non-BMP,
    or non-Unicode characters.
    • Applying display replacement for illegal Unicode characters
    by default (codes ending with FFFE/FFFF, surrogates,
    non-Unicode code points).
    • Fixed a lot of other remaining width display inconsistencies.
  • Making use of window focus out/in reports (xterm 224).
  • Workaround for xterm 224 bug which could lock up the terminal.
  • Adjusting display details to properties of gnome-terminal,
  konsole.
  • Considering termcap information of function key escape
  sequences.
  Miscellaneous changes:
  • Increased speed of some UTF-8 search operations by a
  factor of ~ 40.
  • Colour highlighting of DOS/Mac line end indications.
* Wed Jan 24 2007 mfabian@suse.de
- update to mined 2000.13.2.
  Maintenance release with enhancements in:
  • character input support
  • interoperability
* Mon Oct 16 2006 mfabian@suse.de
- update to mined 2000.13.1
  • Documentation enhancements
* Wed Oct  4 2006 mfabian@suse.de
- update to mined 2000.13
  • Auto-detection and explicit selection of UTF-16 with
    and without BOM (big endian and little endian).
  • Updated to Unicode 5.0.0 (final, from beta2 in 2000.12).
  • Added support for multiple accented character input
  • Additional accent prefix keys for most frequent accents of
    all Latin-based languages (macron, breve, dot above, ogonek,
  caron, stroke).
  • Support for Greek (monotonic and polytonic).
  • Support for Cyrillic accented characters.
  • Revised menu structure to be more intuitive.
  • Improved menu handling system.
  • Making use of xterm 216 mode which provides detection of
    Alt-/Control-modified digits and punctuation keys.
  • Improved support for some legacy terminals.
  •Consistent setting of file access modes when cloning a file
    or creating a new file with executable permission.
* Tue Jul 11 2006 mfabian@suse.de
- update to mined 2000.12.2.
  + Updated to Unicode 5.0.0 beta2
  + Supplemented Big5 character set with HKSCS-2004 update
  + Revised interpretation of locale environment variables
  + Revised terminal encoding handling
  + Supporting lots of additional 8-bit encodings
  + Optional Unicode Copy/Paste buffer mode with implicit conversion
  + Supplemented Cangjie input method with additional mappings from
    HKSCS-2004
  + Case conversion is now always (i.e. in all encodings) based on
    Unicode.
  + Smart quotes enabled in all text encodings.
  + Updated HTML character mnemonics to HTML 4.01.
  + Interworking enhancements: Improved intuitive assignment of
    copy/paste functions to keypad, enhanced flexbility of usage.
  + Further improvements on terminal interworking (even
    version-specific), especially with KDE konsole.
    See also http://bugzilla.novell.com/show_bug.cgi?id=161746
  + Added kterm encoding auto-detection.
- remove hunks from build.patch which are included upstream
- remove do-not-return-random-data-in-function.patch (included
  upstream).
* Wed May 17 2006 schwab@suse.de
- Don't strip binaries.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Aug  5 2005 mfabian@suse.de
- update to 2000.11 (updated to Unicode 4.1.0).
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS -fno-strict-aliasing.
- fixed a harmless buffer overflow.
* Wed Mar  2 2005 mfabian@suse.de
- add another patch from author to improve menu-frames when
  using konsole.
* Tue Mar  1 2005 mfabian@suse.de
- add patch from author to fix the following bugs:
  o  Fixed missing use of terminal capability to "enable alternate
  character set" (terminfo enacs, termcap eA) so graphic menu
  borders should now work in some remaining cases and no longer be
  replaced with letters.
  o Fixed partial scrollbar update logic to prevent gaps in
  scrollbar display.
  o Tweaked panic handling to terminate more smoothly after a
  screen output error (e.g. if output crashes with ncursesw 5.4
  on a more than 3 bytes UTF-8 sequence).
* Fri Feb  4 2005 mfabian@suse.de
- fix mined.desktop file and make it build for SuSE 8.2.
* Thu Feb  3 2005 mfabian@suse.de
- update to 2000.10.
  extract from the author's announcement:
  o Character encoding, CJK, and input support enhancements
    +	Printing feature revamped; now working with all encodings.
    +	Updated character properties to Unicode 4.0.1:
  case conversion, character-to-script mapping, screen width
  (continuing to work with older width data versions by
    terminal auto-detection), keyboard mappings for CJK input
    methods (esp. updated Cangjie keyboard mapping table
    accordingly).
    +	Added support for major mapped 8 bit character encodings.
    +	Added transparent handling of UTF-16 encoded files
    (with BOM).
    +	Full support for combining characters in CJK encodings
  and 8 bit encodings, including optional separated display
    mode and partial editing (within combined character).
    +	Added Han character information
    (description / pronunciation) while browsing text or
    input method pick lists.
    +	Enhanced character information conforming to ISO 14755.
    +	Added keyboard mapping features and added important
    input methods to the default configuration as part of
  the distribution.
    +	Additional input support for CJK, Vietnamese, Thai, Hebrew.
    +	Added radical/stroke lookup input method for CJK characters,
  especially useful for not CJK speaking users.
    +	Revamped mnemonic input support; completed mnemonic patterns
  and enhanced documentation.
    +	Enhanced numeric character input support; conforming to
  ISO 14755.
  o Interactive enhancements
    +	Revamped menu control; added subtitles and flag markers
  (showing active options); enabled menu navigation by item
    letters or mouse wheel movement.
  o Runtime environment enhancements
    +	Enhanced interoperability with various terminals; enhanced
  detection and handling of available menu border styles as
    well as screen attributes used for scrollbar and special
    character display for a wide range of terminals.
    +	Providing runtime support library with X configuration
    patterns and terminal startup scripts.
* Thu May  6 2004 hmacht@suse.de
- added norootforbuild in specfile
* Mon Mar 15 2004 mfabian@suse.de
- update to 2000.9.
  extract from the author's announcement:
  + more compact representation for character set tables and
    keyboard mapping tables. Reduces size of binary more than 700K.
  + encoding autodetection improved
  + Position stack and return function also work across files
    (esp. after identifier definition searches using tags file)
  + Smart quotes: auto-detection of quotation marks style on file loading.
  + Interactive Latin-1 / UTF-8 conversion support.
  + Support for VIM keyboard mapping files.
- remove mined-64bit.patch (included upstream).
* Mon Aug  4 2003 mfabian@suse.de
- update to 2000.8
  extract from the author's announcement:
  New features in this release:
  * Major extension of CJK character set support: GB18030,
    full EUC-JP, CNS (EUC-TW)
  * Vietnamese VISCII character set support
  * Auto-detection of UTF-8 / CJK terminal features
  * Flexible locale configuration for both text and terminal encoding
  * Smart dashes
  * Multiple paste buffers (emacs-style)
  * emacs command mode
  Main enhancements:
  * Revised Japanese input method tables
* Tue May 27 2003 mfabian@suse.de
- update to 2000.7
  extract from the author's announcement:
  New features in this release:
  * Enhanced East Asian input method support;
    selection menu for multiple character choices ("pick list").
  * Support for editing CJK encoded files in UTF-8 terminal; major
    CJK encodings are supported (Big5, GBK, JIS, S-JIS, UHC, Johab).
  Main enhancements:
  * Flag menus for all flags for more intuitive selection.
  * Enhanced and generalized coded character input (CJK / decimal
    / illegal code recognition).
  * Extended bullet recognition for clever justification (auto-indent).
* Tue Mar 25 2003 mfabian@suse.de
- update to 2000.6
  extract from the author's announcement:
  New features:
  * bidirectional terminal support handles Arabic ligature joining
    (LAM/ALEF)
  * new command to go backward and forward along text positions
    after search and other operations
  Main enhancements:
  * Added recognition of mouse wheel control sequences and attached
    according behaviour - untested as I don't have a mouse wheel.
  * New key interpretations for shift-Return (shift-Enter) and
    control-Return (control-Enter) to insert Unicode paragraph
    separators and line separators respectively if Unicode
    line-end handling is enabled.
  * Improved coded and mnemonic character entry on prompt line.
  * Fixed display problems in separated display mode
    (for Unicode combined characters) on the status line.
  * Reviewed various commands for remaining fixes in UTF-8 handling.
- remove errno patch (included upstream)
* Mon Jan 20 2003 mfabian@suse.de
- update to 2000.5
* Mon Dec  2 2002 ro@suse.de
- include errno.h where needed
* Tue Oct  1 2002 mfabian@suse.de
- update to 2000.4
  extract from /usr/share/doc/packages/mined/CHANGES
  * Made use of advanced xterm mouse tracking modes.
  * Syntax highlighting
  * auto-indentation
  * Checkout and checkin functions for version management systems
  * Revised case conversion and other Unicode character
    property handling.
  * Fixed some display bugs
  * Fixed some search pattern match bugs
  * Removed restriction of regular expressions with Unicode
    characters
* Tue Aug  6 2002 mfabian@suse.de
- update to 2000.3
  * updated man page and html documentation
  * some interface improvements and bug fixes
  for details see /usr/share/doc/packages/mined/CHANGES
* Sat Apr 21 2001 mfabian@suse.de
- update tarball, which includes some fixes from the author:
  menu frames are now drawn with graphic characters even on the
  linux console, help file is automatically found in the standard
  location on SuSE Linux: /usr/share/doc/packages/mined/mined.hlp
* Fri Apr 20 2001 mfabian@suse.de
- update to version 2000.2
- remove mined.dif and mined2000-termio.patch (fixes included
  upstream)
- remove mined.man (now included upstream)
* Thu Mar 22 2001 mfabian@suse.de
- add termios/termio patch from werner@suse.de
- bzip2 sources
* Tue Mar 20 2001 mfabian@suse.de
- use ncurses instead of termcap
* Mon Mar  5 2001 mfabian@suse.de
- the fix by stepan@suse.de also makes it compile on ia64
* Thu Jan 25 2001 stepan@suse.de
- prototype fixes for troublefree compilation on Alpha
* Sat Jan 13 2001 mfabian@suse.de
- converted mined.help file to nroff to have a regular manpage
- updated to mined 2000
* Mon Jan  8 2001 mfabian@suse.de
- new package: mined 98 release 5/99
